<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Română [RO]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=433
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Română';
$lang_info['country'] = 'România';  
$lang_info['charset'] = 'utf-8';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'ro';
$lang_info['zero_plural'] = true;

$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d categorie actualizată';
$lang['%d albums updated'] = '%d categorii actualizate';
$lang['%d comment to validate'] = '%d comentariu de validat';
$lang['%d comments to validate'] = '%d comentarii de validat';
$lang['%d new comment'] = '%d nou comentariu';
$lang['%d new comments'] = '%d noi comentarii';
$lang['%d comment'] = '%d comentariu';
$lang['%d comments'] = '%d comentarii';
$lang['%d hit'] = 'vazut %d dată';
$lang['%d hits'] = 'vazut %d ori';
$lang['%d new photo'] = '%d imagine nouă';
$lang['%d new photos'] = '%d imagini noi';
$lang['%d new user'] = '%d utilizator nou';
$lang['%d new users'] = '%d utilizatori noi';
$lang['About'] = 'Despre';
$lang['All tags'] = 'Toate etichetele';
$lang['Any tag'] = 'Orice eticheta';
$lang['At least one listed rule must be satisfied.'] = 'Cel puţin o singură regulă trebuie să fie îndeplinită';
$lang['At least one tag must match'] = 'Cel puţin o etichetă trebuie să se potriveasca';
$lang['Author'] = 'Autor';
$lang['Albums'] = 'Categorii';
$lang['Album'] = 'Categorie';
$lang['Close this window'] = 'Inchide această fereastră';
$lang['Complete RSS feed (photos, comments)'] = 'Flux RSS complet (imagini, comentarii)';
$lang['Confirm Password'] = 'Confirmare parolă';
$lang['Connection settings'] = 'Parametrii de conecţie';
$lang['Login'] = 'Conecţie';
$lang['Contact webmaster'] = 'Contactaţi webmasterul';
$lang['Create a new account'] = 'Creaţi un cont nou';
$lang['Created on'] = 'Creat pe';
$lang['Creation date'] = 'Data creaţiei';
$lang['Current password is wrong'] = 'Parola actuală nu este corectă';
$lang['Dimensions'] = 'Dimensii';
$lang['Display'] = 'Afişare';
$lang['Each listed rule must be satisfied.'] = 'Fiecare regulă enumerată trebuie să fie îndeplinită';
$lang['Email address'] = 'Adresa de e-mail';
$lang['Enter your personnal informations'] = 'Introduceţi informaţiile dvs. personale';
$lang['Error sending email'] = 'Eroare la trimiterea de e-mail';
$lang['File name'] = 'Nume de fişier';
$lang['File'] = 'Fişier';
$lang['Filesize'] = 'Mărime fişier';
$lang['Filter and display'] = 'Filtrează şi afişează';
$lang['Filter'] = 'Filtrează';
$lang['Forgot your password?'] = 'Aţi uitat parola?';
$lang['Go through the gallery as a visitor'] = 'Navigaţi prin galerie ca un vizitator';
$lang['Help'] = 'Ajutor';
$lang['Identification'] = 'Identificare';
$lang['Photos only RSS feed'] = 'RSS feed numai cu imagini';
$lang['Keyword'] = 'Cuvînt cheie';
$lang['Links'] = 'Link-uri';
$lang['N/A'] = 'N/A';
$lang['New on %s'] = 'Nou pe %s';
$lang['New password confirmation does not correspond'] = 'Noua confirmare a parolei nu se potriveşte';
$lang['Notification'] = 'Notificare';
$lang['Number of items'] = 'Numărul de articole';
$lang['Original dimensions'] = 'Dimensiuni originale';
$lang['Password forgotten'] = 'Parola uitată';
$lang['Password'] = 'Parola';
$lang['Post date'] = 'Dată post';
$lang['Posted on'] = 'Postat pe';
$lang['Profile'] = 'Profil';
$lang['Quick connect'] = 'Conectare rapidă';
$lang['RSS feed'] = 'RSS feed';
$lang['Register'] = 'Înscrie';
$lang['Registration'] = 'Înscriere';
$lang['Related tags'] = 'Etichete asociate';
$lang['Reset'] = 'Resetare';
$lang['Retrieve password'] = 'Recuperare parolă';
$lang['Search rules'] = 'Criterii de căutare';
$lang['Search tags'] = 'Caută etichete';
$lang['Search'] = 'Caută';
$lang['display available tags'] = 'Vezi etichetele disponibile';
$lang['Since'] = 'De la';
$lang['Sort by'] = 'Sortare după';
$lang['Sort order'] = 'Ordine de sortare';
$lang['Tag'] = 'Etichetă';
$lang['Tags'] = 'Etichete';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'Notificarea RSS feed prevede notificarea cu privire la noutăţile din acest site: poze noi, categorii actualizate, noi comentarii. Folosiţi un RSS feed reader.';
$lang['Unknown feed identifier'] = 'Identificator RSS feed  necunoscut';
$lang['User comments'] = 'Comentarii utilizator ';
$lang['Username'] = 'Nume de utilizator';
$lang['Visits'] = 'Vizite';
$lang['Webmaster'] = 'Webmaster';
$lang['Week %d'] = 'Săptămâna %d';
$lang['About Piwigo'] = 'Despre Piwigo';
$lang['You are not authorized to access the requested page'] = 'Nu sunteţi autorizat sa accesaţi pagina solicitată';
$lang['add to caddie'] = 'adaugă în cărucior';
$lang['add this photo to your favorites'] = 'adăuga această imagine la favorite';
$lang['Administration'] = 'Administraţie';
$lang['all'] = 'tot';
$lang['ascending'] = 'ascendent';
$lang['author(s) : %s'] = 'autor(i) : %s';
$lang['Expand all albums'] = 'Extinde toate categoriile';
$lang['posted after %s (%s)'] = 'postat după %s (%s)';
$lang['posted before %s (%s)'] = 'postat înainte de %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'postat între %s (%s) şi %s (%s)';
$lang['posted on %s'] = 'postat pe %s';
$lang['Best rated'] = 'Cel mai bun evaluat';
$lang['display best rated photos'] = 'afişează cele mai bune imagini';
$lang['caddie'] = 'cărucior';
$lang['Calendar'] = 'Calendar';
$lang['All'] = 'Tot';
$lang['display each day with photos, month per month'] = 'Afişare an de an, lună de lună, zi de zi';
$lang['View'] = 'Vedere';
$lang['chronology_monthly_calendar'] = 'Calendar lunar';
$lang['chronology_monthly_list'] = 'Lista lunară';
$lang['chronology_weekly_list'] = 'Listă săptămânală ';
$lang['Click here if your browser does not automatically forward you'] = 'Click aici dacă browser-ul nu va trimite în mod automat';
$lang['comment date'] = 'data comentariului';
$lang['Comment'] = 'Comentariu';
$lang['Your comment has been registered'] = 'Comentariul dvs. a fost înregistrat';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Sistem Anti-flood: vă rugăm aşteptaţi o clipă înainte de a încerca să postaţi un alt comentariu';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Comentariul dvs. nu a fost înregistrat deoarece nu a trecut regulile de validare';
$lang['An administrator must authorize your comment before it is visible.'] = 'Un administrator trebuie să autorizeze comentariul dvs. înainte de a deveni vizibil.';
$lang['This login is already used by another user'] = 'Acest nume este deja folosit de un alt utilizator';
$lang['Comments'] = 'Comentarii';
$lang['Add a comment'] = 'Adaugă un comentariu';
$lang['created after %s (%s)'] = 'creat după %s (%s)';
$lang['created before %s (%s)'] = 'create înainte de %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'creat între %s (%s) şi %s (%s)';
$lang['created on %s'] = 'creat pe %s';
$lang['Customize'] = 'Particularizează';
$lang['Your Gallery Customization'] = 'Personalizarea Galeriei dvs.';
$lang['Default'] = 'În mod implicit';
$lang['delete this photo from your favorites'] = 'şterge această imagine din favorite';
$lang['Delete'] = 'Şterge';
$lang['descending'] = 'descendent';
$lang['download'] = 'descărcare';
$lang['download this file'] = 'descărcă acest fişier';
$lang['edit'] = 'editează';
$lang['wrong date'] = 'dată greşită';
$lang['day'][0] = 'Duminică';
$lang['day'][1] = 'Luni';
$lang['day'][2] = 'Marţi';
$lang['day'][3] = 'Miercuri';
$lang['day'][4] = 'Joi';
$lang['day'][5] = 'Vineri';
$lang['day'][6] = 'Sâmbătă';
$lang['excluded'] = 'exclus';
$lang['Your favorites'] = 'Preferatele mele';
$lang['display your favorites photos'] = 'Afişează imaginile mele preferate';
$lang['Favorites'] = 'Preferat(e)';
$lang['First'] = 'Prima(ul)';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Galeria este blocată pentru întreţinere. Vă mulţumim reveniţi mai târziu.';
$lang['Page generated in'] = 'Pagina generată în';
$lang['guest'] = 'vizitator';
$lang['Hello'] = 'Bună ziua';
$lang['available for administrators only'] = 'disponibil numai pentru administratori';
$lang['display this album'] = 'prezintă imagini de la rădăcina acestei categorii';
$lang['display last user comments'] = 'Vezi cele mai recente comentarii ale utilizatorilor';
$lang['customize the appareance of the gallery'] = 'personalizează aspectul galeriei';
$lang['search'] = 'căutare';
$lang['Home'] = 'Prima pagină';
$lang['in this album'] = 'în această categorie';
$lang['in %d sub-album'] = 'în %d sub-categorie';
$lang['in %d sub-albums'] = 'în %d sub-categorii';
$lang['included'] = 'inclus';
$lang['Invalid password!'] = 'Parolă invalidă !';
$lang['Language'] = 'Limbă';
$lang['last %d days'] = 'ultimele %d zile';
$lang['Last'] = 'Ultima(ul)';
$lang['Logout'] = 'Deconectare';
$lang['E-mail address'] = 'Adresa de e-mail';
$lang['obligatory'] = 'obligatorie';
$lang['Maximum photo height'] = 'Înălţimea maximă a imaginii';
$lang['Maximum height must be a number superior to 50'] = 'Înălţimea maximă trebuie să fie mai mare de 50';
$lang['Maximum photo width'] = 'Lăţimea maximă a imaginilor';
$lang['Maximum width must be a number superior to 50'] = 'Lăţimea maximă trebuie să fie mai mare de 50';
$lang['display a calendar by creation date'] = 'afişează un calendar în funcţie de data creării';
$lang['display all photos in all sub-albums'] = 'afişează toate elementele în toate sub-categoriile';
$lang['return to normal view mode'] = 'Înapoi la vizualizarea normală';
$lang['display a calendar by posted date'] = 'afişează un calendar în funcţie de data adăugării';
$lang['Most visited'] = 'Cele mai vizionate';
$lang['display most visited photos'] = 'afişează imaginile cele mai vizionate';
$lang['The number of photos per page must be a not null scalar'] = 'Numărul de imagini pe pagină trebuie să fie un număr întreg nenul';
$lang['Number of photos per page'] = 'Numărul de miniaturi pe pagină';
$lang['Unknown identifier'] = 'Identificator necunoscut ';
$lang['New password'] = 'Parolă nouă';
$lang['Rate this photo'] = 'Evaluează aceasta imagine';
$lang['Next'] = 'Următor(oare)';
$lang['no rate'] = 'nici o evaluare';
$lang['Photos posted within the last %d day.'] = 'Elemente postate în ultima %d zi.';
$lang['Photos posted within the last %d days.'] = 'Elemente postate în ultimele %d zile.';
$lang['password updated'] = 'parolă actualizată';
$lang['Recent period must be a positive integer value'] = 'perioada recentă trebuie să fie un număr întreg pozitiv';
$lang['photo'] = 'imagine';
$lang['Click on the photo to see it in high definition'] = 'Clicaţi pe imagine pentru a o vedea de înaltă definiţie';
$lang['Show file metadata'] = 'Arată metadatele fişierului';
$lang['Powered by'] = 'Realizat de';
$lang['Preferences'] = 'Preferinţe';
$lang['Random photos'] = 'Imagini aleatoare';
$lang['display a set of random photos'] = 'afişează un set de imagini aleatoare';
$lang['Recent albums'] = 'Categorii recente';
$lang['Recent albums'] = 'Categorii recente';
$lang['display recently updated albums'] = 'afişează categoriile create  sau actualizate recent ';
$lang['Recent period'] = 'Recent';
$lang['Recent photos'] = 'Imagini recente';
$lang['display most recent photos'] = 'afişează cele mai recente imagini';
$lang['Redirection...'] = 'Redirecţionare...';
$lang['Please, enter a login'] = 'Vă rugăm, introduceţi un nume de utilizator';
$lang['login mustn\'t end with a space character'] = 'numele de utilizator nu trebuie să se încheie cu un spaţiu';
$lang['login mustn\'t start with a space character'] = 'numele de utilizator nu trebuie sa înceapă cu un spaţiu';
$lang['this login is already used'] = 'acest nume este deja folosit';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'adresa de e-mail trebuie să fie de genul xxx@yyy.eee (de exemplu: jack@altern.org)';
$lang['please enter your password again'] = 'vă rugăm să introduceţi parola din nou';
$lang['Auto login'] = 'Conectare automatică';
$lang['remove this tag from the list'] = 'eliminaţi acesta etichetă de pe lista';
$lang['representative'] = 'reprezentant';
$lang['Search for Author'] = 'Caută autor';
$lang['Search in albums'] = 'Caută în categorii';
$lang['Previous'] = 'Precedent(e)';
$lang['Search by Date'] = 'Căutare după dată';
$lang['Date'] = 'Dată';
$lang['End-Date'] = 'Expiră';
$lang['Kind of date'] = 'Tip de dată';
$lang['Search for words'] = 'Caută cuvinte';
$lang['Search for all terms'] = 'Caută toţi termenii';
$lang['Search for any terms'] = 'Cauta după oricare dintre termeni';
$lang['Empty query. No criteria has been entered.'] = 'Interogare goală. Nici un criteriu nu a fost introdus.';
$lang['Search Options'] = 'Opţiuni de căutare';
$lang['Search results'] = 'Rezultatele căutării';
$lang['Search in sub-albums'] = 'Caută în sub-categorii';
$lang['searched words : %s'] = 'cuvinte căutate : %s';
$lang['Contact'] = 'Contact';
$lang['set as album representative'] = 'Setaţi ca reprezentant al acestei categorii';
$lang['Show number of comments'] = 'Arată numărul de comentarii';
$lang['Show number of hits'] = 'Arată numărul de vizualizări';
$lang['slideshow'] = 'prezentare';
$lang['stop the slideshow'] = 'opreşte prezentarea';
$lang['Specials'] = 'Speciale';
$lang['SQL queries in'] = 'interogări SQL în';
$lang['display only recently posted photos'] = 'Arată numai elementele publicate recent';
$lang['return to the display of all photos'] = 'reveniţi la afişarea tuturor imaginilor';
$lang['the beginning'] = 'începutul';
$lang['Interface theme'] = 'Tema Interfeţei';
$lang['Thumbnails'] = 'Miniaturi';
$lang['Menu'] = 'Meniu';
$lang['A comment on your site'] = 'Un comentariu pe site-ul dvs.';
$lang['today'] = 'azi';
$lang['Update your rating'] = 'Actualizaţi evaluarea dvs.';
$lang['wrong filename'] = 'nume de fişier incorect';
$lang['the username must be given'] = 'numele utilizatorului trebuie să fie specificat';
$lang['useful when password forgotten'] = 'utilă în cazul în care uitaţi parola';
$lang['Quick search'] = 'Căutare rapidă';
$lang['Connected user: %s'] = 'Utilizator conectat : %s';
$lang['IP: %s'] = 'Adresa IP : %s';
$lang['Browser: %s'] = 'Navigator : %s';
$lang['Author: %s'] = 'Autor : %s';
$lang['Comment: %s'] = 'Comentariu : %s';
$lang['Comment by %s'] = 'Comentarii de %s';
$lang['User: %s'] = 'Utilizator: %s';
$lang['Email: %s'] = 'E-mail : %s';
$lang['Admin: %s'] = 'Administraţie : %s';
$lang['Registration of %s'] = 'Înregistrare de %s';
$lang['Album: %s'] = 'Categorie : %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Statutul utilizatorului "invitat" este eronat, se vor folosi  parametrii impliciţi. Va rugăm sa informaţi webmasterul.';
$lang['this email address is already in use'] = 'un alt utilizator foloseşte deja acest e-mail';
$lang['Album results for'] = 'Rezultatele categoriilor pentru';
$lang['Tag results for'] = 'Rezultatele  etichetelor pentru';
$lang['from %s to %s'] = 'de la %s până la %s';
$lang['Play of slideshow'] = 'Startează prezentarea';
$lang['Pause of slideshow'] = 'Pune pe pauză prezentarea';
$lang['Repeat the slideshow'] = 'Repetă prezentarea';
$lang['Not repeat the slideshow'] = 'Nu repeta prezentarea';
$lang['Reduce diaporama speed'] = 'Încetineşte viteza prezentării';
$lang['Accelerate diaporama speed'] = 'Accelerează viteza prezentării';
$lang['Submit'] = 'Execută';
$lang['Yes'] = 'Da';
$lang['No'] = 'Nu';
$lang['%d photo'] = '%d imagine';
$lang['%d photos'] = '%d imagini';
$lang['%d photo is also linked to current tags'] = '%d Imaginea este de asemenea legată de etichetele actuale';
$lang['%d photos are also linked to current tags'] = '%d Imaginile sunt de asemenea legate de etichetele actuale';
$lang['display photos linked to this tag'] = 'Vezi numai imagini legate de această etichetă';
$lang['photos posted during the last %d days'] = 'Imagini adăugate în ultimele %d zile';
$lang['Piwigo Help'] = 'Ajutor pentru Piwigo';
$lang['Rank'] = 'Rang';
$lang['group by letters'] = 'regrupează pe litere';
$lang['letters'] = 'litere';
$lang['show tag cloud'] = 'arată norul de etichete';
$lang['cloud'] = 'nor';
$lang['Reset to default values'] = 'Reveniţi la setările implicite';
$lang['delete all photos from your favorites'] = 'scoate-ţi toate pozele din preferinţele dvs.';
$lang['Sent by'] = 'Trimis de';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Cookie-urile sunt blocate sau nu sunt suportate de browser-ul dumneavoastră. Trebuie să activaţi  cookie-urile pentru a vă conecta.';
$lang['edit this comment'] = 'modifică acest comentariu';
$lang['Edit a comment'] = 'modifică un comentariu';
$lang['Are you sure?'] = 'Sunteţi sigur(ă) ?';
$lang['(!) This comment requires validation'] = '(!) Acest comentariu trebuie să fie validat';
$lang['Welcome'] = 'Bine aţi venit';
$lang['Welcome to your Piwigo photo gallery!'] = 'Bine aţi venit la galeria dvs. foto Piwigo !';
$lang['... or browse your empty gallery'] = '... sau navigaţi prin galeria dvs. vidă';
$lang['... or please deactivate this message, I will find my way by myself'] = '... sau vă rugăm să dezactivaţi acest mesaj, mă voi descurca singur';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Bună ziua %s, galeria dvs. foto Piwigo este vidă !';
$lang['I want to add photos'] = 'Vreau să adaug poze';
$lang['Manage this user comment: %s'] = 'Administrează acest comentariu de utilizator: %s';
$lang['Email address is missing. Please specify an email address.'] = 'Adresa de email lipseşte. Vă rugăm să specificaţi o adresă de e-mail.';
$lang['This author modified following comment:'] = 'Acest autor a modificat următorul comentariu :';
$lang['This author removed the comment with id %d'] = 'Acest autor a şters comentariul cu id-ul %d';
$lang['delete this comment'] = 'şterge acest comentariu';
$lang['validate this comment'] = 'validează acest comentariu';
$lang['month'][10] = 'Octombrie';
$lang['month'][11] = 'Noiembrie';
$lang['month'][12] = 'Decembrie';
$lang['month'][1] = 'Ianuarie';
$lang['month'][2] = 'Februarie';
$lang['month'][3] = 'Martie';
$lang['month'][4] = 'Aprilie';
$lang['month'][5] = 'Mai';
$lang['month'][6] = 'Iunie';
$lang['month'][7] = 'Iulie';
$lang['month'][8] = 'August';
$lang['month'][9] = 'Septembrie';
$lang['html tags are not allowed in login'] = 'tag-urile HTML nu sunt permise în login';

?>